@@ -5,7 +5,6 @@ import numpy as np
 import pandas as pd
 from collections.abc import Callable
 from typing import List
-from matplotlib.pyplot import Figure
 from matplotlib.axes import Axes
 
 
@@ -513,7 +512,89 @@ class ExportBase:
                 yMerge))
         return self
 
-    def exportCDFExcel(self, savePath: str,
+    def _get_statistical_info_dataframe(self):
+        statistics_columns = [
+            'Node', 'Label', 'Units', 'Sample Counts',
+            'Sum', 'Avg', 'Mean', 'Var', 'std'
+        ]
+        statistics_data = []
+        for item in self.items:
+            statistics_data.append([
+                item.nodeName,
+                item.label,
+                item.units,
+                len(item.y),
+                round(np.sum(item.y), 3),
+                round(np.average(item.y), 3),
+                round(np.mean(item.y), 3),
+                round(np.var(item.y), 3),
+                round(np.std(item.y), 3)
+            ])
+
+        return pd.DataFrame(statistics_data, columns=statistics_columns)
+
+    def save_statistical_info_as_csv(
+            self, save_dir: str, filename: str
+    ):
+        if not os.path.exists(save_dir):
+            os.makedirs(save_dir)
+        self._get_statistical_info_dataframe(). \
+            to_csv(f"{save_dir}{os.sep}{filename}")
+        return self
+
+    def save_statistical_info_as_excel(
+            self, save_dir: str, filename: str
+    ):
+        if not os.path.exists(save_dir):
+            os.makedirs(save_dir)
+        self._get_statistical_info_dataframe(). \
+            to_excel(f"{save_dir}{os.sep}{filename}")
+        return self
+
+    def print_statistical_info_as_latex(self):
+        print(self._get_statistical_info_dataframe().style.to_latex())
+        return self
+
+    def print_statistical_info_as_table(self, title: str):
+        """
+        以表格的形式打印统计信息
+        :return:
+        """
+        from rich.console import Console
+        from rich.table import Table
+        console = Console()
+
+        table = Table(show_header=True,
+                      header_style="bold magenta",
+                      title=title, expand=True)
+        table.add_column("Node", justify="center", no_wrap=True)
+        table.add_column("Label", justify="center", no_wrap=True)
+        table.add_column("Units", justify="center", no_wrap=True)
+        table.add_column("Sample Counts", justify="center", no_wrap=True)
+        table.add_column("Sum", justify="center", no_wrap=True)
+        table.add_column("Average", justify="center", no_wrap=True)
+        table.add_column("Mean", justify="center", no_wrap=True)
+        table.add_column("Var", justify="center", no_wrap=True)
+        table.add_column("Std", justify="center", no_wrap=True)
+        for item in self.items:
+            table.add_row(
+                item.nodeName,
+                item.label,
+                item.units,
+                str(len(item.y)),
+                str(round(np.sum(item.y), 3)),
+                str(round(np.average(item.y), 3)),
+                str(round(np.mean(item.y), 3)),
+                str(round(np.var(item.y), 3)),
+                str(round(np.std(item.y), 3))
+            )
+        console.print(table)
+        return self
+
+    def exportCDFExcel(self,
+                       save_dir: str,
+                       filename: str,
+                       savePath: str,
                        xName: str = "Rate",
                        yName: str = "CDF"):
         """
@@ -523,6 +604,9 @@ class ExportBase:
         :param savePath:
         :return:
         """
+        if not os.path.exists(save_dir):
+            os.makedirs(save_dir)
+        save_path = f"{save_dir}{os.sep}{filename}"
         longNames, units, labels = [], [], []
         ys, maxLen = [], 0
 
@@ -559,10 +643,12 @@ class ExportBase:
             contents.append(dataMatrix[:, i])
 
         df = pd.DataFrame(contents)
-        df.to_excel(savePath, index=False, header=None)
+        df.to_excel(save_path, index=False, header=None)
         return self
 
-    def exportExcel(self, savePath: str,
+    def exportExcel(self,
+                    save_dir: str,
+                    filename: str,
                     xName: str = "Times",
                     yName: str = "Rate",
                     xUnit: str = "Second"):
@@ -574,6 +660,9 @@ class ExportBase:
         :param xUnit:
         :return:
         """
+        if not os.path.exists(save_dir):
+            os.makedirs(save_dir)
+        save_path = f"{save_dir}{os.sep}{filename}"
         contents = []
         nodeNames, units, labels, xResult = [], [], [], []
         for item in self.items:
@@ -603,5 +692,5 @@ class ExportBase:
             contents.append(dataMatrix[:, i])
 
         df = pd.DataFrame(contents)
-        df.to_excel(savePath, index=False, header=None)
+        df.to_excel(save_path, index=False, header=None)
         return self
